Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 15211)
+++ wp-includes/post.php	(working copy)
@@ -673,7 +673,7 @@
  * @return bool Whether post type is hierarchical.
  */
 function is_post_type_hierarchical( $post_type ) {
-	if ( ! is_post_type( $post_type ) )
+	if ( ! post_type_exists( $post_type ) )
 		return false;
 
 	$post_type = get_post_type_object( $post_type );
@@ -684,12 +684,12 @@
  * Checks if a post type is registered.
  *
  * @since 3.0.0
- * @uses get_post_type()
+ * @uses get_post_type_object()
  *
  * @param string Post type name
  * @return bool Whether post type is registered.
  */
-function is_post_type( $post_type ) {
+function post_type_exists( $post_type ) {
 	return (bool) get_post_type_object( $post_type );
 }
 
Index: wp-includes/default-widgets.php
===================================================================
--- wp-includes/default-widgets.php	(revision 15211)
+++ wp-includes/default-widgets.php	(working copy)
@@ -1041,7 +1041,7 @@
 	}
 
 	function _get_current_taxonomy($instance) {
-		if ( !empty($instance['taxonomy']) && is_taxonomy($instance['taxonomy']) )
+		if ( !empty($instance['taxonomy']) && taxonomy_exists($instance['taxonomy']) )
 			return $instance['taxonomy'];
 
 		return 'post_tag';
Index: wp-includes/deprecated.php
===================================================================
--- wp-includes/deprecated.php	(revision 15211)
+++ wp-includes/deprecated.php	(working copy)
@@ -2513,3 +2513,53 @@
 	_deprecated_function( __FUNCTION__, '3.0' );
 	return '';
 }
+
+/**
+ * Checks if a post type is registered.
+ *
+ * @since 3.0.0
+ * @deprecated 3.0.0
+ * @deprecated Use post_type_exists()
+ * @see post_type_exists()
+ *
+ * @param string Post type name
+ * @return bool Whether post type is registered.
+ */
+function is_post_type( $post_type ) {
+	_deprecated_function( __FUNCTION__, '3.0', 'post_type_exists()' );
+	return post_type_exists( $post_type );
+}
+
+/**
+ * Checks that the taxonomy name exists.
+ *
+ * @since 2.3.0
+ * @deprecated 3.0.0
+ * @deprecated Use taxonomy_exists()
+ * @see taxonomy_exists()
+ *
+ * @param string $taxonomy Name of taxonomy object
+ * @return bool Whether the taxonomy exists.
+ */
+function is_taxonomy( $taxonomy ) {
+	_deprecated_function( __FUNCTION__, '3.0', 'taxonomy_exists()' );
+	return taxonomy_exists( $post_type );
+}
+
+/**
+ * Check if Term exists.
+ *
+ * @since 2.3.0
+ * @deprecated 3.0.0
+ * @deprecated Use term_exists()
+ * @see term_exists()
+ *
+ * @param int|string $term The term to check
+ * @param string $taxonomy The taxonomy name to use
+ * @param int $parent ID of parent term under which to confine the exists search.
+ * @return mixed Get the term id or Term Object, if exists.
+ */
+function is_term( $term, $taxonomy = '', $parent = 0 ) {
+	_deprecated_function( __FUNCTION__, '3.0', 'term_exists()' );
+	return term_exists( $term, $taxonomy, $parent );
+}
\ No newline at end of file
Index: wp-includes/category-template.php
===================================================================
--- wp-includes/category-template.php	(revision 15211)
+++ wp-includes/category-template.php	(working copy)
@@ -482,7 +482,7 @@
 
 	extract( $r );
 
-	if ( !is_taxonomy($taxonomy) )
+	if ( !taxonomy_exists($taxonomy) )
 		return false;
 
 	$categories = get_categories( $r );
Index: wp-admin/admin-ajax.php
===================================================================
--- wp-admin/admin-ajax.php	(revision 15211)
+++ wp-admin/admin-ajax.php	(working copy)
@@ -237,7 +237,7 @@
 		$category_nicename = sanitize_title($cat_name);
 		if ( '' === $category_nicename )
 			continue;
-		if ( !($cat_id = is_term($cat_name, $taxonomy->name, $parent)) ) {
+		if ( !($cat_id = term_exists($cat_name, $taxonomy->name, $parent)) ) {
 			$new_term = wp_insert_term($cat_name, $taxonomy->name, array('parent' => $parent));
 			$cat_id = $new_term['term_id'];
 		}
@@ -501,7 +501,7 @@
 		$slug = sanitize_title($cat_name);
 		if ( '' === $slug )
 			continue;
-		if ( !$cat_id = is_term( $cat_name, 'link_category' ) ) {
+		if ( !$cat_id = term_exists( $cat_name, 'link_category' ) ) {
 			$cat_id = wp_insert_term( $cat_name, 'link_category' );
 		}
 		$cat_id = $cat_id['term_id'];
Index: wp-admin/includes/taxonomy.php
===================================================================
--- wp-admin/includes/taxonomy.php	(revision 15211)
+++ wp-admin/includes/taxonomy.php	(working copy)
@@ -19,7 +19,7 @@
  * @return unknown
  */
 function category_exists($cat_name, $parent = 0) {
-	$id = is_term($cat_name, 'category', $parent);
+	$id = term_exists($cat_name, 'category', $parent);
 	if ( is_array($id) )
 		$id = $id['term_id'];
 	return $id;
@@ -240,7 +240,7 @@
  * @return unknown
  */
 function tag_exists($tag_name) {
-	return is_term($tag_name, 'post_tag');
+	return term_exists($tag_name, 'post_tag');
 }
 
 /**
@@ -264,7 +264,7 @@
  * @return unknown
  */
 function wp_create_term($tag_name, $taxonomy = 'post_tag') {
-	if ( $id = is_term($tag_name, $taxonomy) )
+	if ( $id = term_exists($tag_name, $taxonomy) )
 		return $id;
 
 	return wp_insert_term($tag_name, $taxonomy);
Index: wp-admin/includes/nav-menu.php
===================================================================
--- wp-admin/includes/nav-menu.php	(revision 15214)
+++ wp-admin/includes/nav-menu.php	(working copy)
@@ -274,7 +274,7 @@
 	}
 
 	if ( 'get-post-item' == $type ) {
-		if ( get_post_type_object( $object_type ) ) {
+		if ( post_type_exists( $object_type ) ) {
 			if ( isset( $request['ID'] ) ) {
 				$object_id = (int) $request['ID'];
 				if ( 'markup' == $response_format ) {
@@ -291,7 +291,7 @@
 					echo "\n";
 				}
 			}
-		} elseif ( is_taxonomy( $object_type ) ) {
+		} elseif ( taxonomy_exists( $object_type ) ) {
 			if ( isset( $request['ID'] ) ) {
 				$object_id = (int) $request['ID'];
 				if ( 'markup' == $response_format ) {
Index: wp-admin/edit-tags.php
===================================================================
--- wp-admin/edit-tags.php	(revision 15211)
+++ wp-admin/edit-tags.php	(working copy)
@@ -14,7 +14,7 @@
 if ( empty($taxonomy) )
 	$taxonomy = 'post_tag';
 
-if ( !is_taxonomy($taxonomy) )
+if ( !taxonomy_exists($taxonomy) )
 	wp_die(__('Invalid taxonomy'));
 
 $tax = get_taxonomy($taxonomy);

Index: wp-includes/taxonomy.php
===================================================================
--- wp-includes/taxonomy.php	(revision 15211)
+++ wp-includes/taxonomy.php	(working copy)
@@ -142,7 +142,7 @@
  * @since 2.3.0
  *
  * @uses $wp_taxonomies
  * @uses is_taxonomy() Checks whether taxonomy exists
  *
  * @param string $taxonomy Name of taxonomy object to return
  * @return object|bool The Taxonomy Object or false if $taxonomy doesn't exist
@@ -150,7 +150,7 @@
 function get_taxonomy( $taxonomy ) {
 	global $wp_taxonomies;
 
-	if ( ! is_taxonomy($taxonomy) )
+	if ( ! taxonomy_exists( $taxonomy ) )
 		return false;
 
 	return $wp_taxonomies[$taxonomy];
@@ -159,19 +159,21 @@
 /**
  * Checks that the taxonomy name exists.
  *
+ * Formerly is_taxonomy(), introduced in 2.3.0.
+ *
  * @package WordPress
  * @subpackage Taxonomy
- * @since 2.3.0
+ * @since 3.0.0
  *
  * @uses $wp_taxonomies
  *
  * @param string $taxonomy Name of taxonomy object
  * @return bool Whether the taxonomy exists.
  */
-function is_taxonomy( $taxonomy ) {
+function taxonomy_exists( $taxonomy ) {
 	global $wp_taxonomies;
 
-	return isset($wp_taxonomies[$taxonomy]);
+	return isset( $wp_taxonomies[$taxonomy] );
 }
 
 /**
@@ -186,14 +188,14 @@
  * @subpackage Taxonomy
  * @since 2.3.0
  *
  * @uses is_taxonomy() Checks whether taxonomy exists
  * @uses get_taxonomy() Used to get the taxonomy object
  *
  * @param string $taxonomy Name of taxonomy object
  * @return bool Whether the taxonomy is hierarchical
  */
 function is_taxonomy_hierarchical($taxonomy) {
-	if ( ! is_taxonomy($taxonomy) )
+	if ( ! taxonomy_exists($taxonomy) )
 		return false;
 
 	$taxonomy = get_taxonomy($taxonomy);
@@ -208,7 +210,7 @@
  * parameter), along with strings for the taxonomy name and another string for
  * the object type.
  *
  * Nothing is returned, so expect error maybe or use is_taxonomy() to check
  * whether taxonomy exists.
  *
  * Optional $args contents:
@@ -437,7 +439,7 @@
 		$taxonomies = array( $taxonomies );
 
 	foreach ( (array) $taxonomies as $taxonomy ) {
-		if ( ! is_taxonomy( $taxonomy ) )
+		if ( ! taxonomy_exists( $taxonomy ) )
 			return new WP_Error( 'invalid_taxonomy', __( 'Invalid Taxonomy' ) );
 	}
 
@@ -509,7 +511,7 @@
 		return $error;
 	}
 
-	if ( ! is_taxonomy($taxonomy) ) {
+	if ( ! taxonomy_exists($taxonomy) ) {
 		$error = new WP_Error('invalid_taxonomy', __('Invalid Taxonomy'));
 		return $error;
 	}
@@ -576,7 +578,7 @@
 function get_term_by($field, $value, $taxonomy, $output = OBJECT, $filter = 'raw') {
 	global $wpdb;
 
-	if ( ! is_taxonomy($taxonomy) )
+	if ( ! taxonomy_exists($taxonomy) )
 		return false;
 
 	if ( 'slug' == $field ) {
@@ -634,7 +636,7 @@
  * @return array|WP_Error List of Term Objects. WP_Error returned if $taxonomy does not exist
  */
 function get_term_children( $term_id, $taxonomy ) {
-	if ( ! is_taxonomy($taxonomy) )
+	if ( ! taxonomy_exists($taxonomy) )
 		return new WP_Error('invalid_taxonomy', __('Invalid Taxonomy'));
 
 	$term_id = intval( $term_id );
@@ -819,7 +821,7 @@
 	}
 
 	foreach ( (array) $taxonomies as $taxonomy ) {
-		if ( ! is_taxonomy($taxonomy) ) {
+		if ( ! taxonomy_exists($taxonomy) ) {
 			$error = & new WP_Error('invalid_taxonomy', __('Invalid Taxonomy'));
 			return $error;
 		}
@@ -1071,9 +1073,11 @@
  *
  * Returns the index of a defined term, or 0 (false) if the term doesn't exist.
  *
+ * Formerly is_term(), introduced in 2.3.0.
+ *
  * @package WordPress
  * @subpackage Taxonomy
- * @since 2.3.0
+ * @since 3.0.0
  *
  * @uses $wpdb
  *
@@ -1082,7 +1086,7 @@
  * @param int $parent ID of parent term under which to confine the exists search.
  * @return mixed Get the term id or Term Object, if exists.
  */
-function is_term($term, $taxonomy = '', $parent = 0) {
+function term_exists($term, $taxonomy = '', $parent = 0) {
 	global $wpdb;
 
 	$select = "SELECT term_id FROM $wpdb->terms as t WHERE ";
@@ -1343,7 +1347,7 @@
 
 	$term = (int) $term;
 
-	if ( ! $ids = is_term($term, $taxonomy) )
+	if ( ! $ids = term_exists($term, $taxonomy) )
 		return false;
 	if ( is_wp_error( $ids ) )
 		return $ids;
@@ -1356,7 +1360,7 @@
 
 	if ( isset($default) ) {
 		$default = (int) $default;
-		if ( ! is_term($default, $taxonomy) )
+		if ( ! term_exists($default, $taxonomy) )
 			unset($default);
 	}
 
@@ -1443,7 +1447,7 @@
 		$taxonomies = array($taxonomies);
 
 	foreach ( (array) $taxonomies as $taxonomy ) {
-		if ( ! is_taxonomy($taxonomy) )
+		if ( ! taxonomy_exists($taxonomy) )
 			return new WP_Error('invalid_taxonomy', __('Invalid Taxonomy'));
 	}
 
@@ -1581,7 +1585,7 @@
 function wp_insert_term( $term, $taxonomy, $args = array() ) {
 	global $wpdb;
 
-	if ( ! is_taxonomy($taxonomy) )
+	if ( ! taxonomy_exists($taxonomy) )
 		return new WP_Error('invalid_taxonomy', __('Invalid taxonomy'));
 
 	$term = apply_filters( 'pre_insert_term', $term, $taxonomy );
@@ -1623,10 +1627,10 @@
 		}
 	}
 
-	if ( $term_id = is_term($slug) ) {
+	if ( $term_id = term_exists($slug) ) {
 		$existing_term = $wpdb->get_row( $wpdb->prepare( "SELECT name FROM $wpdb->terms WHERE term_id = %d", $term_id), ARRAY_A );
 		// We've got an existing term in the same taxonomy, which matches the name of the new term:
-		if ( is_taxonomy_hierarchical($taxonomy) && $existing_term['name'] == $name && is_term( (int) $term_id, $taxonomy ) ) {
+		if ( is_taxonomy_hierarchical($taxonomy) && $existing_term['name'] == $name && term_exists( (int) $term_id, $taxonomy ) ) {
 			// Hierarchical, and it matches an existing term, Do not allow same "name" in the same level.
 			$siblings = get_terms($taxonomy, array('fields' => 'names', 'get' => 'all', 'parent' => (int)$parent) );
 			if ( in_array($name, $siblings) ) {
@@ -1643,7 +1647,7 @@
 			if ( false === $wpdb->insert( $wpdb->terms, compact( 'name', 'slug', 'term_group' ) ) )
 				return new WP_Error('db_insert_error', __('Could not insert term into the database'), $wpdb->last_error);
 			$term_id = (int) $wpdb->insert_id;
-		} elseif ( is_term( (int) $term_id, $taxonomy ) )  {
+		} elseif ( term_exists( (int) $term_id, $taxonomy ) )  {
 			// Same name, same slug.
 			return new WP_Error('term_exists', __('A term with the name provided already exists.'));
 		}
@@ -1712,7 +1716,7 @@
 
 	$object_id = (int) $object_id;
 
-	if ( ! is_taxonomy($taxonomy) )
+	if ( ! taxonomy_exists($taxonomy) )
 		return new WP_Error('invalid_taxonomy', __('Invalid Taxonomy'));
 
 	if ( !is_array($terms) )
@@ -1730,7 +1734,7 @@
 		if ( !strlen(trim($term)) )
 			continue;
 
-		if ( !$term_info = is_term($term, $taxonomy) ) {
+		if ( !$term_info = term_exists($term, $taxonomy) ) {
 			// Skip if a non-existent term ID is passed.
 			if ( is_int($term) )
 				continue;
@@ -1805,7 +1809,7 @@
 function wp_unique_term_slug($slug, $term) {
 	global $wpdb;
 
-	if ( ! is_term( $slug ) )
+	if ( ! term_exists( $slug ) )
 		return $slug;
 
 	// If the taxonomy supports hierarchy and the term has a parent, make the slug unique
@@ -1817,7 +1821,7 @@
 			if ( is_wp_error($parent_term) || empty($parent_term) )
 				break;
 			$slug .= '-' . $parent_term->slug;
-			if ( ! is_term( $slug ) )
+			if ( ! term_exists( $slug ) )
 				return $slug;
 
 			if ( empty($parent_term->parent) )
@@ -1883,7 +1887,7 @@
 function wp_update_term( $term_id, $taxonomy, $args = array() ) {
 	global $wpdb;
 
-	if ( ! is_taxonomy($taxonomy) )
+	if ( ! taxonomy_exists($taxonomy) )
 		return new WP_Error('invalid_taxonomy', __('Invalid taxonomy'));
 
 	$term_id = (int) $term_id;
@@ -142,7 +142,7 @@
  *
  * @uses $wp_taxonomies
- * @uses is_taxonomy() Checks whether taxonomy exists
+ * @uses taxonomy_exists() Checks whether taxonomy exists
  *
  * @param string $taxonomy Name of taxonomy object to return
@@ -186,14 +188,14 @@
  * @since 2.3.0
  *
- * @uses is_taxonomy() Checks whether taxonomy exists
+ * @uses taxonomy_exists() Checks whether taxonomy exists
  * @uses get_taxonomy() Used to get the taxonomy object
  *
@@ -208,7 +210,7 @@
  * the object type.
  *
- * Nothing is returned, so expect error maybe or use is_taxonomy() to check
+ * Nothing is returned, so expect error maybe or use taxonomy_exists() to check
  * whether taxonomy exists.
  *